/*
 * BreadCrumbException.cs
 *
 * Bread Crumb Trail Control
 * Version: 2.0
 *
 * Copyright (c) 2004, 2006, TopCoder, Inc. All rights reserved
 *
 * Authors: elefth, Standlove
 *          Pops, TCSDEVELOPER
 */

using System;
using System.Runtime.Serialization;

namespace TopCoder.Web.UI.WebControl.BreadCrumb
{
    /// <summary>
    /// The exception that is thrown in all cases where the <see cref="BreadCrumbTrailControl"/>
    /// cannot correctly parse, format, and write bread crumb trail.
    /// </summary>
    ///
    /// <remarks>
    /// This exception can be thrown by practically any class in the system.
    /// However the disposition of the exception is dependent upon the
    /// <see cref="BreadCrumbTrailControl.ErrorDisposition"/> setting.
    /// The exception may be silently ignored, may be rendered
    /// into the output of the page, or rethrown to the IIS engine.
    /// </remarks>
    ///
    /// <threadsafety static="true" instance="true"/>
    [Serializable]
    public class BreadCrumbException : ApplicationException
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="BreadCrumbException"/> class.
        /// </summary>
        ///
        /// <remarks>
        /// Please note that this constructor is never used in this component.
        /// </remarks>
        public BreadCrumbException()
            : base()
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="BreadCrumbException"/> class
        /// with a specified error message.
        /// </summary>
        ///
        /// <param name="message">
        /// The message that describes the error.
        /// </param>
        public BreadCrumbException(string message)
            : base(message)
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="BreadCrumbException"/> class
        /// with a specified error message and a reference to the inner exception
        /// that is the cause of this exception.
        /// </summary>
        ///
        /// <param name="message">
        /// The message that describes the error.
        /// </param>
        /// <param name="cause">
        /// The exception that is the cause of the current exception.
        /// </param>
        public BreadCrumbException(string message, Exception cause)
            : base(message, cause)
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="BreadCrumbException"/> class
        /// with serialized data.
        /// </summary>
        ///
        /// <param name="info">
        /// The object that holds the serialized object data.
        /// </param>
        /// <param name="context">
        /// The contextual information about the source or destination.
        /// </param>
        protected BreadCrumbException(SerializationInfo info, StreamingContext context)
            : base(info, context)
        {
        }
    }
}
