/*
 * MyAnchorPathWriter.cs
 *
 * Bread Crumb Trail Control
 * Version: 2.0
 *
 * Copyright (c) 2004, 2006, TopCoder, Inc. All rights reserved
 *
 * Authors: Standlove, TCSDEVELOPER
 */

using System;
using System.Web.UI;

namespace TopCoder.Web.UI.WebControl.BreadCrumb.PathWriter.Tests
{
    /// <summary>
    /// A derived class from <see cref="AnchorPathWriter"/>
    /// that exposes the protected method via a public method.
    /// </summary>
    ///
    /// <remarks>
    /// This class provides a single method <see cref="MyWriteNode"/>
    /// which simply delegates the call to the protected <see cref="AnchorPathWriter.WriteNode"/>
    /// so that testing can be simplified to this single method.
    /// </remarks>
    ///
    /// <threadsafety static="true" instance="true"/>
    public class MyAnchorPathWriter : AnchorPathWriter
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MyAnchorPathWriter"/> class.
        /// </summary>
        public MyAnchorPathWriter()
        {
            // do nothing
        }

        /// <summary>
        /// Simply forwards the call to the protected <see cref="AnchorPathWriter.WriteNode"/>.
        /// </summary>
        ///
        /// <param name="writer">
        /// A non-null writer to write to.
        /// </param>
        /// <param name="node">
        /// A non-null node to write.
        /// </param>
        /// <param name="nodeStyle">
        /// A style class to use for the node or null if no style should be used.
        /// </param>
        /// <param name="mouseOverStyle">
        /// The mouse over style class to use or null for none.
        /// </param>
        ///
        /// <exception cref="ArgumentNullException">
        /// <paramref name="writer"/> or <paramref name="node"/> is null.
        /// </exception>
        /// <exception cref="BreadCrumbException">
        /// Any error occurs writing the node.
        /// </exception>
        public void MyWriteNode(
            HtmlTextWriter writer, BreadCrumbNode node, string nodeStyle, string mouseOverStyle)
        {
            WriteNode(writer, node, nodeStyle, mouseOverStyle);
        }
    }
}
