/*
 * MyOrderedListPathWriter.cs
 *
 * Bread Crumb Trail Control
 * Version: 2.0
 *
 * Copyright (c) 2004, 2006, TopCoder, Inc. All rights reserved
 *
 * Authors: Standlove, TCSDEVELOPER
 */

using System;
using System.Web.UI;

namespace TopCoder.Web.UI.WebControl.BreadCrumb.PathWriter.Tests
{
    /// <summary>
    /// A derived class from <see cref="OrderedListPathWriter"/>
    /// that exposes all the protected methods via public methods.
    /// </summary>
    ///
    /// <remarks>
    /// This class provides public methodx MyXXX
    /// which simply delegates the call to the corresponding protected XXX methods
    /// so that testing can be simplified.
    /// </remarks>
    ///
    /// <threadsafety static="true" instance="true"/>
    public class MyOrderedListPathWriter : OrderedListPathWriter
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MyOrderedListPathWriter"/> class.
        /// </summary>
        public MyOrderedListPathWriter()
        {
            // do nothing
        }

        /// <summary>
        /// Simply forwards the call to the protected <see cref="OrderedListPathWriter.BeginPath"/>.
        /// </summary>
        ///
        /// <param name="writer">
        /// A non-null writer to use.
        /// </param>
        ///
        /// <exception cref="ArgumentNullException">
        /// <paramref name="writer"/> is a null reference.
        /// </exception>
        /// <exception cref="BreadCrumbException">
        /// An exception occurs writing the beginning tag for the ordered list.
        /// </exception>
        public void MyBeginPath(HtmlTextWriter writer)
        {
            BeginPath(writer);
        }

        /// <summary>
        /// Simply forwards the call to the protected <see cref="OrderedListPathWriter.WriteNode"/>.
        /// </summary>
        ///
        /// <param name="writer">
        /// A non-null writer to write to.
        /// </param>
        /// <param name="node">
        /// A non-null node to write.
        /// </param>
        /// <param name="nodeStyle">
        /// A style class to use for the node or null if no style should be used.
        /// </param>
        /// <param name="mouseOverStyle">
        /// The mouse over style class to use or null for none.
        /// </param>
        ///
        /// <exception cref="ArgumentNullException">
        /// <paramref name="writer"/> is null or <paramref name="node"/> has a null Url.
        /// </exception>
        /// <exception cref="BreadCrumbException">
        /// Any error occurs writing the node.
        /// </exception>
        public void MyWriteNode(
            HtmlTextWriter writer, BreadCrumbNode node, string nodeStyle, string mouseOverStyle)
        {
            WriteNode(writer, node, nodeStyle, mouseOverStyle);
        }

        /// <summary>
        /// Simply forwards the call to the protected <see cref="OrderedListPathWriter.WriteSeparator"/>.
        /// </summary>
        ///
        /// <param name="writer">
        /// A non-null writer to use.
        /// </param>
        /// <param name="parent">
        /// A non-null parent control.
        /// </param>
        public void MyWriteSeparator(HtmlTextWriter writer, BreadCrumbTrailControl parent)
        {
            WriteSeparator(writer, parent);
        }

        /// <summary>
        /// Simply forwards the call to the protected <see cref="OrderedListPathWriter.EndPath"/>.
        /// </summary>
        ///
        /// <param name="writer">
        /// A non-null writer to use.
        /// </param>
        ///
        /// <exception cref="ArgumentNullException">
        /// <paramref name="writer"/> is a null reference.
        /// </exception>
        /// <exception cref="BreadCrumbException">
        /// An exception occurs writing the ending tag for the ordered list.
        /// </exception>
        public void MyEndPath(HtmlTextWriter writer)
        {
            EndPath(writer);
        }
    }
}
